/* This file was generated by syncqt. */
#ifndef QT_QTEGLSUPPORT_VERSION_H
#define QT_QTEGLSUPPORT_VERSION_H

#define QTEGLSUPPORT_VERSION_STR "5.9.5"

#define QTEGLSUPPORT_VERSION 0x050905

#endif // QT_QTEGLSUPPORT_VERSION_H
